@@ -276,7 +276,7 @@ namespace Twitterizer.Core
                 // Try to read the error message, if there is one.
                 try
                 {
-                    TwitterErrorDetails errorDetails = SerializationHelper<TwitterErrorDetails>.Deserialize(responseData);
+                    var errorDetails = SerializationHelper<TwitterErrorDetails>.Deserialize(twitterResponse.Content);
                     twitterResponse.ErrorMessage = errorDetails.ErrorMessage;
                 }
                 catch (Exception)
@@ -420,8 +420,9 @@ namespace Twitterizer.Core
         /// <returns>An enum of the current access level of the OAuth Token being used.</returns>
         private AccessLevel ParseAccessLevel(WebHeaderCollection responseHeaders)
         {
-            if (responseHeaders.AllKeys.Contains("X-Access-Level"))
-            {
+            if (responseHeaders.AllKeys.Any(
+                x => x.Equals("X-Access-Level",
+                              StringComparison.InvariantCultureIgnoreCase))) {
                 switch (responseHeaders["X-Access-Level"].ToLower())
                 {
                     case "read":
