@@ -76,10 +76,10 @@ namespace Twitterizer.Commands
             }
 
             if (options.SinceStatusId > 0)
-                this.RequestParameters.Add("since_id", options.SinceStatusId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("since_id", options.SinceStatusId.ToString("#"));
 
             if (options.MaxStatusId > 0)
-                this.RequestParameters.Add("max_id", options.MaxStatusId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("max_id", options.MaxStatusId.ToString("#"));
 
             if (options.Count > 0)
                 this.RequestParameters.Add("count", options.Count.ToString(CultureInfo.InvariantCulture));
