@@ -52,7 +52,7 @@ namespace Twitterizer.Commands
         /// <param name="tokens">The tokens.</param>
         /// <param name="options">The options.</param>
         public ListFavoritesCommand(OAuthTokens tokens, ListFavoritesOptions options)
-            : base(HTTPVerb.GET, "favorites.json", tokens, options)
+            : base(HTTPVerb.GET, "favorites/list.json", tokens, options)
         {
             if (tokens == null && (options == null || string.IsNullOrEmpty(options.UserNameOrId)))
             {
@@ -74,7 +74,7 @@ namespace Twitterizer.Commands
                 this.RequestParameters.Add("page", "1");
                 return;
             }
-
+            
             this.RequestParameters.Add("page", options.Page > 0 ? options.Page.ToString(CultureInfo.InvariantCulture) : "1");
 
             if (!string.IsNullOrEmpty(options.UserNameOrId))
@@ -86,6 +86,12 @@ namespace Twitterizer.Commands
             {
                 this.RequestParameters.Add("count", options.Count.ToString(CultureInfo.InvariantCulture));
             }
+
+            if (options.SinceStatusId > 0)
+                this.RequestParameters.Add("since_id", options.SinceStatusId.ToString("#"));
+
+            if (options.MaxStatusId > 0)
+                this.RequestParameters.Add("max_id", options.MaxStatusId.ToString("#"));
         }
     }
 }
