@@ -59,5 +59,17 @@ namespace Twitterizer
         /// </summary>
         /// <value>The page number.</value>
         public int Page { get; set; }
+
+        /// <summary>
+        /// Gets or sets the minimum (earliest) status id to request.
+        /// </summary>
+        /// <value>The since id.</value>
+        public decimal SinceStatusId { get; set; }
+
+        /// <summary>
+        /// Gets or sets the max (latest) status id to request.
+        /// </summary>
+        /// <value>The max id.</value>
+        public decimal MaxStatusId { get; set; }
     }
 }
