@@ -25,5 +25,19 @@ namespace agsXMPP.protocol.client
 {
     public delegate void MessageHandler (object sender, Message msg);
     public delegate void PresenceHandler(object sender, Presence pres);
-    public delegate void IqHandler      (object sender, IQ iq);
+    public delegate void IqHandler      (object sender, IQEventArgs args);
+
+    public class IQEventArgs : EventArgs
+    {
+        public IQ IQ { get; private set; }
+        public bool Handled { get; set; }
+
+        public IQEventArgs(IQ iq)
+        {
+            if (iq == null) {
+                throw new ArgumentNullException("iq");
+            }
+            IQ = iq;
+        }
+    }
 }
