@@ -1,3 +1,5 @@
+// This file is part of Smuxi and is licensed under the terms of MIT/X11
+//
 // Copyright (c) 2009.  Tom Kaminski
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -17,7 +19,6 @@
 // LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 // THE SOFTWARE.
-
 using System;
 using System.Security.Cryptography;
 
@@ -107,7 +108,7 @@ namespace Smuxi.Common
         }
         public uint CrcValue {
             get {
-                return (uint)((HashValue[0] << 24) | (HashValue[1] << 16) | (HashValue[2] << 8) | HashValue[3]);
+                return (uint)(((uint)HashValue[0] << 24) | (HashValue[1] << 16) | (HashValue[2] << 8) | HashValue[3]);
             }
         }
         public override int HashSize {
