@@ -25,11 +25,11 @@ namespace Smuxi.Common
 {
     public static class Defines
     {
-        public const string GitBranch   = "release/1.1";
-        public const string GitCommitHash = "b0476480";
+        public const string GitBranch   = "master";
+        public const string GitCommitHash = "ca69d07c";
 
         private static readonly string f_InstallPrefix = "/usr/local";
-        private static readonly string f_DistVersion = "release/1.1/b0476480";
+        private static readonly string f_DistVersion = "master/ca69d07c";
         private static readonly string f_TwitterApiKey = "60QV2qQx9cS7y1BJDbgAA|2VgD6qQKddsF5HYQ0TrRgs3tFTnCwDONBmRlTmG658";
 
         public static string InstallPrefix {
