@@ -1,33 +1,27 @@
-/*
- * $Id: Page.cs 111 2006-02-20 23:10:45Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GtkGnome/Page.cs $
- * $Rev: 111 $
- * $Author: meebey $
- * $Date: 2006-02-21 00:10:45 +0100 (Tue, 21 Feb 2006) $
- *
- * Smuxi - Smart MUltipleXed Irc
- *
- * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
- *
- * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
- */
-
+// This file is part of Smuxi and is licensed under the terms of MIT/X11
+//
+// Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to deal
+// in the Software without restriction, including without limitation the rights
+// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+// copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+// THE SOFTWARE.
 using System;
 using System.Text;
+using System.Runtime.Remoting;
 using System.Reflection;
 using System.Collections;
 using System.Diagnostics;
@@ -115,37 +109,24 @@ namespace Smuxi.Common
         
         private static string _Parameterize(MethodBase method, params object[] parameters)
         {
-            StringBuilder res = new StringBuilder();
             ParameterInfo[] parameter_info = method.GetParameters();
-            if (parameter_info.Length > 0) {
-                res.Append(parameter_info[0].Name).Append(" = ");
+            if (parameter_info.Length == 0) {
+                return String.Empty;
+            }
+            StringBuilder res = new StringBuilder();
+            for (int i = 0; i < parameter_info.Length; i++) {
+                res.Append(parameter_info[i].Name).Append(" = ");
                 if (parameters == null) {
                     res.Append(_ParameterizeQuote(null));
-                } else if (parameters != null && parameters.Length > 0) {
-                    res.Append(_ParameterizeQuote(parameters[0]));
+                } else if (parameters != null && parameters.Length > i) {
+                    res.Append(_ParameterizeQuote(parameters[i]));
                 } else {
                     // empty array
                     res.Append("[]");
                 }
-                
-                for (int i = 1; i < parameter_info.Length; i++) {
-                    res.Append(", ");
-                    
-                    res.Append(parameter_info[i].Name).Append(" = ");
-                    if (parameters == null) {
-                        res.Append(_ParameterizeQuote(null));
-                    } else if (parameters != null && parameters.Length > i) {
-                        res.Append(_ParameterizeQuote(parameters[i]));
-                    } else {
-                        // empty array
-                        res.Append("[]");
-                    }
-                }
-            } else {
-                // no parameters
-                res.Append(String.Empty);
+                res.Append(", ");
             }
-
+            res.Remove(res.Length - 2, 2);
             return res.ToString();
         }
 
@@ -155,6 +136,11 @@ namespace Smuxi.Common
                 return "(null)";
             }
 
+            // OPT: tracing over remote objects is too expensive!
+            if (RemotingServices.IsTransparentProxy(obj)) {
+                return obj.GetType().ToString();
+            }
+
             StringBuilder line = new StringBuilder();
             if (obj is string) {
                 line.Append("'").Append(obj).Append("'");
