@@ -321,16 +321,6 @@ namespace Smuxi.Engine
             prefix = "Engine/Users/DEFAULT/MessageBuffer/Persistent/";
             Get(prefix+"MaxCapacity", 50 * 1000);
 
-            prefix = "Engine/Users/DEFAULT/Servers/";
-            Get(prefix + "Servers", new string[] {
-                "IRC/irc.oftc.net",
-                "IRC/irc.gimp.org",
-                "IRC/irc.geekshed.net",
-                "IRC/irc.efnet.org",
-                "IRC/irc.ircnet.org",
-                "IRC/irc.freenode.net"
-            });
-            
             prefix = "Engine/Users/DEFAULT/Servers/IRC/irc.oftc.net/";
             Get(prefix + "Hostname", "irc.oftc.net");
             Get(prefix + "Port", 6667);
@@ -391,18 +381,28 @@ namespace Smuxi.Engine
             Get(prefix + "Password", String.Empty);
             Get(prefix + "UseEncryption", false);
             Get(prefix + "ValidateServerCertificate", false);
-                
-            prefix = "Engine/Users/DEFAULT/Servers/IRC/irc.freenode.net/";
-            Get(prefix + "Hostname", "irc.freenode.net");
-            Get(prefix + "Port", 6667);
-            Get(prefix + "Network", "freenode");
-            Get(prefix + "Nickname", String.Empty);
-            Get(prefix + "Realname", String.Empty);
-            Get(prefix + "Username", String.Empty);
-            Get(prefix + "Password", String.Empty);
-            Get(prefix + "UseEncryption", false);
-            Get(prefix + "ValidateServerCertificate", false);
-            
+
+            prefix = "Engine/Users/DEFAULT/Servers/IRC/irc.libera.chat/";
+            Get (prefix + "Hostname", "irc.libera.chat");
+            Get (prefix + "Port", 6667);
+            Get (prefix + "Network", "Libera.Chat");
+            Get (prefix + "Nickname", String.Empty);
+            Get (prefix + "Realname", String.Empty);
+            Get (prefix + "Username", String.Empty);
+            Get (prefix + "Password", String.Empty);
+            Get (prefix + "UseEncryption", false);
+            Get (prefix + "ValidateServerCertificate", false);
+
+            prefix = "Engine/Users/DEFAULT/Servers/";
+            Get(prefix + "Servers", new string[] {
+                "IRC/irc.oftc.net",
+                "IRC/irc.gimp.org",
+                "IRC/irc.geekshed.net",
+                "IRC/irc.efnet.org",
+                "IRC/irc.ircnet.org",
+                "IRC/irc.libera.chat"
+            });
+
             prefix = "Engine/Users/";
             Get(prefix+"Users", new string[] { "local" });
             
