@@ -1,7 +1,8 @@
 // Smuxi - Smart MUltipleXed Irc
 // 
-// Copyright (c) 2010-2014 Mirco Bauer <meebey@meebey.net>
+// Copyright (c) 2010-2017 Mirco Bauer <meebey@meebey.net>
 // Copyright (c) 2013 Oliver Schneider <mail@oli-obk.de>
+// Copyright (c) 2016 Andres G. Aragoneses <knocte@gmail.com>
 // 
 // Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 // 
@@ -59,6 +60,15 @@ namespace Smuxi.Engine
             }
         }
 
+        public string ID {
+            get {
+                return Message.ID;
+            }
+            set {
+                Message.ID = value;
+            }
+        }
+
         public bool IsEmpty {
             get {
                 return Message.IsEmpty;
@@ -478,6 +488,13 @@ namespace Smuxi.Engine
             MarkAsHighlight();
         }
 
+        public virtual void MarkHighlights(PersonModel sender)
+        {
+            if (sender != Me) {
+                MarkHighlights();
+            }
+        }
+
         public virtual void MarkAsHighlight()
         {
             // colorize the whole message
@@ -876,15 +893,30 @@ namespace Smuxi.Engine
             
             int lastindex = 0;
             do {
-                var groupValues = new string[match.Groups.Count];
-                int i = 0;
-                foreach (Group @group in match.Groups) {
-                    groupValues[i++] = @group.Value;
+                var startDelimiterLength = 0;
+                var regexDelimiterForStartOfPatternValue = match.Groups[MessageBuilderSettings.StartDelimiterGroupName];
+                if (regexDelimiterForStartOfPatternValue != null) {
+                    startDelimiterLength = regexDelimiterForStartOfPatternValue.Value.Length;
                 }
-                
+                var endDelimiterLength = 0;
+                var regexDelimiterForEndOfPatternValue = match.Groups[MessageBuilderSettings.EndDelimiterGroupName];
+                if (regexDelimiterForEndOfPatternValue != null) {
+                    endDelimiterLength = regexDelimiterForEndOfPatternValue.Value.Length;
+                }
+
+                var groupValues = match.Groups.Cast<Group>()
+
+                    // don't get the delimiter because it only determines
+                    // the start or end of pattern, which is not part of the pattern
+                    .Where(g => g != regexDelimiterForStartOfPatternValue &&
+                                g != regexDelimiterForEndOfPatternValue)
+
+                    .Select(g => g.Value).ToArray();
+
                 string url;
                 if (String.IsNullOrEmpty(pattern.LinkFormat)) {
                     url = match.Value;
+                    url = url.Substring(0 + startDelimiterLength, url.Length - (startDelimiterLength - endDelimiterLength));
                 } else {
                     url = String.Format(pattern.LinkFormat, groupValues);
                 }
@@ -894,13 +926,14 @@ namespace Smuxi.Engine
                 } else {
                     text = String.Format(pattern.TextFormat, groupValues);
                 }
+                text = text.Substring(0 + startDelimiterLength, text.Length - (startDelimiterLength + endDelimiterLength));
 
                 if (lastindex != match.Index) {
                     // there were some non-matching-chars before the match
                     // copy that to a TextMessagePartModel
                     var notMatchPart = new TextMessagePartModel(textPart);
                     // only take the proper chunk of text
-                    notMatchPart.Text = textPart.Text.Substring(lastindex, match.Index - lastindex);
+                    notMatchPart.Text = textPart.Text.Substring(lastindex, match.Index + startDelimiterLength - lastindex);
                     // and try other patterns on this part
                     var parts = ParsePatterns(notMatchPart, remainingPatterns);
                     foreach (var part in parts) {
@@ -919,12 +952,12 @@ namespace Smuxi.Engine
                     msgPart = new TextMessagePartModel(text);
                 }
                 msgParts.Add(msgPart);
-                lastindex = match.Index + match.Length;
+                lastindex = match.Index + match.Length - endDelimiterLength;
                 match = match.NextMatch();
             } while (match.Success);
             
             if (lastindex != textPart.Text.Length) {
-                // there were some non-url-chars before this url
+                // there were some non-matching-chars after the last match
                 // copy TextMessagePartModel
                 var notMatchPart = new TextMessagePartModel(textPart);
                 // only take the proper chunk of text
