@@ -41,7 +41,6 @@ namespace Smuxi.Frontend.Gnome
         private static readonly log4net.ILog _Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
 #endif
         private static readonly string    _Name = "Smuxi";
-        private static readonly string    _GladeFilename = "smuxi-frontend-gnome.glade";
         private static readonly string    _UIName = "GNOME";
         private static int                _UIThreadID;
         private static Version            _Version;
@@ -80,12 +79,6 @@ namespace Smuxi.Frontend.Gnome
             }
         }
         
-        public static string GladeFilename {
-            get {
-                return _GladeFilename;
-            }
-        }
-        
         public static string UIName {
             get {
                 return _UIName;
@@ -196,6 +189,8 @@ namespace Smuxi.Frontend.Gnome
 
 #if LOG4NET
             _Logger.Info(_VersionString + " starting");
+            var runtimeDescription = System.Runtime.InteropServices.RuntimeInformation.FrameworkDescription;
+            _Logger.Info($"using .NET runtime: {runtimeDescription}");
 #endif
 
             InitSignalHandlers();
@@ -804,6 +799,8 @@ namespace Smuxi.Frontend.Gnome
             }
 
             // supported:
+            // smuxi://<network name>/#smuxi
+            // smuxi://<server host>/#smuxi
             // smuxi://freenode/#smuxi
             // smuxi://freenode/#%23csharp (##csharp)
             // irc://#smuxi
@@ -834,8 +831,10 @@ namespace Smuxi.Frontend.Gnome
             var linkProtocol = link.Scheme;
             var linkHost = link.Host;
             string linkNetwork = null;
-            if (!linkHost.Contains(".")) {
-                // this seems to be a network name
+            var serverSettings = new ServerListController(UserConfig);
+            // find server model by network name
+            if (serverSettings.GetServerByNetwork(linkHost) != null) {
+                // found a server, thus the host part in "link" is a network name
                 linkNetwork = linkHost;
             }
 
@@ -878,7 +877,6 @@ namespace Smuxi.Frontend.Gnome
                 ServerModel server = null;
                 if (!String.IsNullOrEmpty(linkNetwork)) {
                     // try to find a server with this network name and connect to it
-                    var serverSettings = new ServerListController(UserConfig);
                     server = serverSettings.GetServerByNetwork(linkNetwork);
                     if (server == null) {
                         // in case someone tried an unknown network
@@ -893,16 +891,18 @@ namespace Smuxi.Frontend.Gnome
                         Port = linkPort
                     };
                 }
-                if (server != null) {
+                if (server != null && server.Protocol != "smuxi") {
+                    // connect to server, except the protocol is "smuxi" thus not known
                     manager = Session.Connect(server, FrontendManager);
                 }
             }
 
             if (String.IsNullOrEmpty(linkChat)) {
+                // no chat name was supplied, e.g. irc://freenode/, so we are done here
                 return true;
             }
 
-            // switch to existing chat
+            // find and switch to open chat view
             foreach (var chatView in MainWindow.ChatViewManager.Chats) {
                 if (manager != null && chatView.ProtocolManager != manager) {
                     continue;
