@@ -1,6 +1,6 @@
 // Smuxi - Smart MUltipleXed Irc
 // 
-// Copyright (c) 2011 Mirco Bauer <meebey@meebey.net>
+// Copyright (c) 2011, 2013, 2015 Mirco Bauer <meebey@meebey.net>
 // 
 // Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 // 
@@ -20,6 +20,7 @@
 
 #if IPC_DBUS
 using System;
+using System.Threading;
     #if DBUS_SHARP
 using DBus;
     #else
@@ -90,13 +91,24 @@ namespace Smuxi.Frontend.Gnome
         {
             BusG.Init();
 
-            if (!Bus.System.NameHasOwner(BusName)) {
+            var dbus = Bus.System;
+            if (!dbus.NameHasOwner(BusName)) {
+#if LOG4NET
+                Logger.Info("Init(): no DBus provider for network manager found, " +
+                            "disabling...");
+#endif
                 return;
             }
 
-            Manager = Bus.System.GetObject<INetworkManager>(
+            Manager = dbus.GetObject<INetworkManager>(
                 BusName, new ObjectPath(ObjectPath)
             );
+            if (Manager == null) {
+#if LOG4NET
+                Logger.Warn("Init(): DBus object is null, bailing out!");
+#endif
+                return;
+            }
             Manager.StateChanged += OnStateChanged;
 
             IsInitialized = true;
@@ -129,7 +141,15 @@ namespace Smuxi.Frontend.Gnome
                     if (WasLocalEngine) {
                         // reconnect local protocol managers
                         foreach (var protocolManager in Frontend.Session.ProtocolManagers) {
-                            protocolManager.Reconnect(Frontend.FrontendManager);
+                            var pm = protocolManager;
+                            // run in background so it can't block the GUI
+                            ThreadPool.QueueUserWorkItem(delegate {
+                                try {
+                                    pm.Reconnect(Frontend.FrontendManager);
+                                } catch (Exception ex) {
+                                    Frontend.ShowException(ex);
+                                }
+                            });
                         }
                     } else {
                         Frontend.ReconnectEngineToGUI(false);
