@@ -112,6 +112,12 @@ namespace Smuxi.Frontend.Gnome
             f_OpenLogToolAction.IconName = Gtk.Stock.Open;
             f_FindGroupChatToolAction.IconName = Gtk.Stock.Find;
 
+            // disable the open log buttons initially as they will only be
+            // enabled for chats that have a log file in
+            // MainWindow.OnNotebookSwitchPage()
+            f_OpenLogAction.Sensitive = false;
+            f_OpenLogToolAction.Sensitive = false;
+
             f_MenuToolbar.ShowAll();
             f_MenuToolbar.NoShowAll = true;
             f_MenuToolbar.Visible = (bool) Frontend.FrontendConfig["ShowToolBar"];
@@ -136,27 +142,31 @@ namespace Smuxi.Frontend.Gnome
             f_ShowStatusbarAction.Active = (bool) Frontend.FrontendConfig["ShowStatusBar"];
 
             if (Frontend.IsMacOSX) {
-                // Smuxi menu is already shown as app menu
-                f_SmuxiAction.Visible = false;
-                // About item is already shown in app menu
-                f_AboutAction.Visible = false;
+                try {
+                    IgeMacMenu.GlobalKeyHandlerEnabled = true;
+                    IgeMacMenu.MenuBar = f_MenuBar;
+                    f_ShowMenubarAction.Active = false;
+                    // no need for the menu bar as have the app menu
+                    f_ShowMenubarAction.Visible = false;
 
-                IgeMacMenu.GlobalKeyHandlerEnabled = true;
-                IgeMacMenu.MenuBar = f_MenuBar;
-                f_ShowMenubarAction.Active = false;
-                // no need for the menu bar as have the app menu
-                f_ShowMenubarAction.Visible = false;
+                    var appGroup = IgeMacMenu.AddAppMenuGroup();
+                    appGroup.AddMenuItem(
+                        (Gtk.MenuItem) f_AboutAction.CreateMenuItem(),
+                        _("About Smuxi")
+                    );
+                    var prefItem = (Gtk.MenuItem) f_PreferencesAction.CreateMenuItem();
+                    // TODO: add cmd+, accelerator
+                    appGroup.AddMenuItem(prefItem, _("Preferences"));
+                    IgeMacMenu.QuitMenuItem = (Gtk.MenuItem)
+                        f_QuitAction.CreateMenuItem();
 
-                var appGroup = IgeMacMenu.AddAppMenuGroup();
-                appGroup.AddMenuItem(
-                    (Gtk.MenuItem) f_AboutAction.CreateMenuItem(),
-                    _("About Smuxi")
-                );
-                var prefItem = (Gtk.MenuItem) f_PreferencesAction.CreateMenuItem();
-                // TODO: add cmd+, accelerator
-                appGroup.AddMenuItem(prefItem, _("Preferences"));
-                IgeMacMenu.QuitMenuItem = (Gtk.MenuItem)
-                    f_QuitAction.CreateMenuItem();
+                    // Smuxi menu is already shown as app menu
+                    f_SmuxiAction.Visible = false;
+                    // About item is already shown in app menu
+                    f_AboutAction.Visible = false;
+                } catch (EntryPointNotFoundException ex) {
+                    f_Logger.Error("Failed to initialize mac menu integration, disabling mac menu integration", ex);
+                }
             }
         }
 
@@ -178,7 +188,9 @@ namespace Smuxi.Frontend.Gnome
             Trace.Call(sender, e);
             
             try {
-                var dialog = new PreferencesDialog(Parent);
+                var builder = new Gtk.Builder(null, "PreferencesDialog2.ui", null);
+                var widget = (Gtk.Widget) builder.GetObject("PreferencesDialog");
+                var dialog = new PreferencesDialog(Parent, builder, widget.Handle);
                 dialog.Show();
             } catch (Exception ex) {
                 Frontend.ShowException(Parent, ex);
@@ -227,6 +239,7 @@ namespace Smuxi.Frontend.Gnome
                             server.ServerID = null;
                             server.Nickname = null;
                             server.Realname = null;
+                            server.ClientCertificateFilename = null;
                         }
                         Frontend.Session.Connect(server, Frontend.FrontendManager);
                     } catch (Exception ex) {
@@ -275,8 +288,11 @@ namespace Smuxi.Frontend.Gnome
             Trace.Call(sender, e);
             
             try {
-                var dialog = new PreferencesDialog(Parent);
-                dialog.CurrentPage = PreferencesDialog.Page.Servers;
+                var builder = new Gtk.Builder(null, "PreferencesDialog2.ui", null);
+                var widget = (Gtk.Widget) builder.GetObject("PreferencesDialog");
+                var dialog = new PreferencesDialog(Parent, builder, widget.Handle);
+                dialog.CurrentCategory = PreferencesDialog.Category.Servers;
+                dialog.Show();
             } catch (Exception ex) {
                 Frontend.ShowException(Parent, ex);
             }
@@ -345,11 +361,10 @@ namespace Smuxi.Frontend.Gnome
             Trace.Call(sender, e);
 
             try {
+                var logFile = ChatViewManager.CurrentChatView.ChatModel.LogFile;
                 ThreadPool.QueueUserWorkItem(delegate {
                     try {
-                        SysDiag.Process.Start(
-                            ChatViewManager.CurrentChatView.ChatModel.LogFile
-                        );
+                        SysDiag.Process.Start(logFile);
                     } catch (Exception ex) {
                         Frontend.ShowError(Parent, ex);
                     }
