@@ -1,7 +1,7 @@
 /*
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2009-2015 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2009-2015, 2017 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -41,7 +41,7 @@ namespace Smuxi.Frontend.Gnome
         private static readonly Gdk.Cursor _LinkCursor = new Gdk.Cursor(Gdk.CursorType.Hand2);
         static readonly Regex NickRegex = new Regex("^(<([^ ]+)> )");
         static bool IsGtk2_17 { get; set; }
-        private Gtk.TextTagTable _MessageTextTagTable;
+        protected Gtk.TextTagTable _MessageTextTagTable;
         private MessageModel _LastMessage;
         private bool         _ShowTimestamps;
         private bool         _ShowHighlight;
@@ -57,7 +57,7 @@ namespace Smuxi.Frontend.Gnome
         Gtk.TextTag BoldTag { get; set; }
         Gtk.TextTag ItalicTag { get; set; }
         Gtk.TextTag UnderlineTag { get; set; }
-        Gtk.TextTag LinkTag { get; set; }
+        protected Gtk.TextTag LinkTag { get; set; }
         Gtk.TextTag EventTag { get; set; }
 
         Gtk.TextTag PersonTag { get; set; }
@@ -305,15 +305,6 @@ namespace Smuxi.Frontend.Gnome
                 return;
             }
 
-            int width, height;
-            int widthPango, heightPango;
-            int descent;
-            using (var layout = CreatePangoLayout(null)) {
-                layout.GetPixelSize(out width, out height);
-                layout.GetSize(out widthPango, out heightPango);
-                descent = layout.Context.GetMetrics(layout.FontDescription, null).Descent;
-            }
-
             // A mark here serves two pusposes. One is to allow us to apply the
             // tag across the pixbuf. It also lets us know later where to put
             // the pixbuf if we need to load it from the network
@@ -325,13 +316,7 @@ namespace Smuxi.Frontend.Gnome
             if (EmojiCache.TryGetIcon("emojione", emojiName, out emojiPath)) {
                 var emojiFile = new FileInfo(emojiPath);
                 if (emojiFile.Exists && emojiFile.Length > 0) {
-                    var pix = new Gdk.Pixbuf(emojiPath, -1, height);
-                    buffer.InsertPixbuf(ref iter, pix);
-                    var beforeIter = buffer.GetIterAtMark(mark);
-                    var imgTag = new EmojiTag(mark, emojiFile.FullName);
-                    imgTag.Rise = - descent;
-                    _MessageTextTagTable.Add(imgTag);
-                    buffer.ApplyTag(imgTag, beforeIter, iter);
+                    AddEmoji(buffer, ref iter, imgPart, shortName, mark, emojiPath);
                 } else {
                     AddAlternativeText(buffer, ref iter, imgPart);
                 }
@@ -343,13 +328,8 @@ namespace Smuxi.Frontend.Gnome
             EmojiCache.BeginDownloadFile("emojione", emojiName, emojiUrl,
                 (path) => {
                     GLib.Idle.Add(delegate {
-                        var afterIter = buffer.GetIterAtMark(mark);
-                        buffer.InsertPixbuf(ref afterIter, new Gdk.Pixbuf(path, -1, height));
-                        var beforeIter = buffer.GetIterAtMark(mark);
-                        var emojiTag = new EmojiTag(mark, path);
-                        _MessageTextTagTable.Add(emojiTag);
-                        emojiTag.Rise = - descent;
-                        buffer.ApplyTag(emojiTag, beforeIter, afterIter);
+                        var markIter = buffer.GetIterAtMark(mark);
+                        AddEmoji(buffer, ref markIter, imgPart, shortName, mark, path);
                         return false;
                     });
                 },
@@ -364,6 +344,50 @@ namespace Smuxi.Frontend.Gnome
             );
         }
 
+        void AddEmoji(Gtk.TextBuffer buffer, ref Gtk.TextIter iter,
+                      ImageMessagePartModel imgPart, string shortName,
+                      Gtk.TextMark emojiMark , string imagePath)
+        {
+            int width, height;
+            int descent;
+            using (var layout = CreatePangoLayout(null)) {
+                layout.GetPixelSize(out width, out height);
+                descent = layout.Context.GetMetrics(layout.FontDescription, null).Descent;
+            }
+
+            Gdk.Pixbuf emojiPixBuf;
+            try {
+                emojiPixBuf = new Gdk.Pixbuf(imagePath, -1, height);
+            } catch (Exception ex) {
+#if LOG4NET
+                _Logger.ErrorFormat(
+                    "AddEmoji(): error loading " +
+                    "image file: '{0}' " +
+                    "emoji: '{1}' into Gdk.Pixbuf(), " +
+                    "Exception: {2}",
+                    imagePath, shortName, ex
+                );
+#endif
+
+                // delete the broken image file, maybe after the
+                // next download this will be a valid image
+                File.Delete(imagePath);
+
+                // show alternative text as fallback instead
+                buffer.DeleteMark(emojiMark);
+                AddAlternativeText(buffer, ref iter, imgPart);
+                return;
+            }
+
+            buffer.InsertPixbuf(ref iter, emojiPixBuf);
+            var beforeIter = buffer.GetIterAtMark(emojiMark);
+            var emojiTag = new EmojiTag(emojiMark, imagePath) {
+                Rise =  - descent
+            };
+            _MessageTextTagTable.Add(emojiTag);
+            buffer.ApplyTag(emojiTag, beforeIter, iter);
+        }
+
         public void AddMessage(MessageModel msg)
         {
             AddMessage(msg, true);
@@ -374,6 +398,13 @@ namespace Smuxi.Frontend.Gnome
             AddMessage(msg, addLinebreak, _ShowTimestamps);
         }
 
+        protected virtual void InsertTimeStamp(Gtk.TextBuffer buffer, ref Gtk.TextIter iter,
+                                               string timestamp, MessageModel msg)
+        {
+            timestamp = String.Format("{0} ", timestamp);
+            buffer.Insert(ref iter, timestamp);
+        }
+
         public void AddMessage(MessageModel msg, bool addLinebreak, bool showTimestamps)
         {
 #if MSG_DEBUG
@@ -433,8 +464,7 @@ namespace Smuxi.Frontend.Gnome
                 }
 
                 if (timestamp != null) {
-                    timestamp = String.Format("{0} ", timestamp);
-                    buffer.Insert(ref iter, timestamp);
+                    InsertTimeStamp(buffer, ref iter, timestamp, msg);
 
                     // apply timestamp width to indent tag
                     if (indentTag != null) {
@@ -455,99 +485,11 @@ namespace Smuxi.Frontend.Gnome
 
                 // TODO: implement all types
                 if (msgPart is UrlMessagePartModel) {
-                    var urlPart = (UrlMessagePartModel) msgPart;
-                    var linkText = urlPart.Text ?? urlPart.Url;
-
-                    Uri uri;
-                    try {
-                        uri = new Uri(urlPart.Url);
-                    } catch (UriFormatException ex) {
-#if LOG4NET
-                        _Logger.Error("AddMessage(): Invalid URL: " + urlPart.Url, ex);
-#endif
-                        buffer.Insert(ref iter, linkText);
-                        continue;
-                    }
-
-                    var tags = new List<Gtk.TextTag>();
-                    // link URI tag
-                    var linkTag = new LinkTag(uri);
-                    linkTag.TextEvent += OnLinkTagTextEvent;
-                    _MessageTextTagTable.Add(linkTag);
-                    tags.Add(linkTag);
-
-                    // link style tag
-                    tags.Add(LinkTag);
-
-                    buffer.InsertWithTags(ref iter, linkText, tags.ToArray());
+                    InsertToBuffer(buffer, ref iter, (UrlMessagePartModel) msgPart);
                 } else if (msgPart is TextMessagePartModel) {
-                    var tags = new List<Gtk.TextTag>();
-                    TextMessagePartModel fmsgti = (TextMessagePartModel) msgPart;
-                    if (fmsgti.Text == null) {
-                        // Gtk.TextBuffer.Insert*() asserts on text == NULL
-                        continue;
-                    }
-                    if (fmsgti.ForegroundColor != TextColor.None) {
-                        var bg = ColorConverter.GetTextColor(BackgroundColor);
-                        if (fmsgti.BackgroundColor != TextColor.None) {
-                            bg = fmsgti.BackgroundColor;
-                        }
-                        TextColor color = TextColorTools.GetBestTextColor(
-                            fmsgti.ForegroundColor, bg
-                        );
-                        string tagname = GetTextTagName(color, null);
-                        var tag = _MessageTextTagTable.Lookup(tagname);
-                        tags.Add(tag);
-                    }
-                    if (fmsgti.BackgroundColor != TextColor.None) {
-                        // TODO: get this from ChatView
-                        string tagname = GetTextTagName(null, fmsgti.BackgroundColor);
-                        var tag = _MessageTextTagTable.Lookup(tagname);
-                        tags.Add(tag);
-                    }
-                    if (fmsgti.Underline) {
-#if LOG4NET && MSG_DEBUG
-                        _Logger.Debug("AddMessage(): fmsgti.Underline is true");
-#endif
-                        tags.Add(UnderlineTag);
-                    }
-                    if (fmsgti.Bold) {
-#if LOG4NET && MSG_DEBUG
-                        _Logger.Debug("AddMessage(): fmsgti.Bold is true");
-#endif
-                        tags.Add(BoldTag);
-                    }
-                    if (fmsgti.Italic) {
-#if LOG4NET && MSG_DEBUG
-                        _Logger.Debug("AddMessage(): fmsgti.Italic is true");
-#endif
-                        tags.Add(ItalicTag);
-                    }
-
-                    if (tags.Count > 0) {
-                        buffer.InsertWithTags(ref iter, fmsgti.Text, tags.ToArray());
-                    } else {
-                        buffer.Insert(ref iter, fmsgti.Text);
-                    }
+                    InsertToBuffer(buffer, ref iter, (TextMessagePartModel) msgPart);
                 } else if (msgPart is ImageMessagePartModel) {
-                    var imgpart = (ImageMessagePartModel) msgPart;
-                    Uri uri = null;
-                    string scheme = null;
-                    try {
-                        uri = new Uri(imgpart.ImageFileName);
-                        scheme = uri.Scheme;
-                    } catch (UriFormatException) {
-                        AddAlternativeText(buffer, ref iter, imgpart);
-                    }
-                    switch (scheme) {
-                        case "smuxi-emoji":
-                            var shortName = uri.Host;
-                            AddEmoji(buffer, ref iter, imgpart, shortName);
-                            break;
-                        default:
-                            AddAlternativeText(buffer, ref iter, imgpart);
-                            break;
-                    }
+                    InsertToBuffer(buffer, ref iter, (ImageMessagePartModel) msgPart);
                 }
             }
             var startIter = buffer.GetIterAtMark(startMark);
@@ -604,6 +546,107 @@ namespace Smuxi.Frontend.Gnome
             _LastMessage = msg;
         }
 
+        private void InsertToBuffer(Gtk.TextBuffer buffer, ref Gtk.TextIter iter, UrlMessagePartModel urlPart)
+        {
+            var linkText = urlPart.Text ?? urlPart.Url;
+
+            Uri uri;
+            try {
+                uri = new Uri(urlPart.Url);
+            } catch (UriFormatException ex) {
+#if LOG4NET
+                _Logger.Error("AddMessage(): Invalid URL: " + urlPart.Url, ex);
+#endif
+                buffer.Insert(ref iter, linkText);
+                return;
+            }
+
+            var tags = new List<Gtk.TextTag>();
+            // link URI tag
+            var linkTag = new LinkTag(uri);
+            linkTag.TextEvent += OnLinkTagTextEvent;
+            _MessageTextTagTable.Add(linkTag);
+            tags.Add(linkTag);
+
+            // link style tag
+            tags.Add(LinkTag);
+
+            buffer.InsertWithTags(ref iter, linkText, tags.ToArray());
+        }
+
+        private void InsertToBuffer(Gtk.TextBuffer buffer, ref Gtk.TextIter iter, TextMessagePartModel fmsgti)
+        {
+            var tags = new List<Gtk.TextTag>();
+            if (fmsgti.Text == null) {
+                // Gtk.TextBuffer.Insert*() asserts on text == NULL
+                return;
+            }
+            if (fmsgti.ForegroundColor != TextColor.None) {
+                var bg = ColorConverter.GetTextColor(BackgroundColor);
+                if (fmsgti.BackgroundColor != TextColor.None) {
+                    bg = fmsgti.BackgroundColor;
+                }
+                TextColor color = TextColorTools.GetBestTextColor(
+                    fmsgti.ForegroundColor, bg
+                );
+                string tagname = GetTextTagName(color, null);
+                var tag = _MessageTextTagTable.Lookup(tagname);
+                tags.Add(tag);
+            }
+            if (fmsgti.BackgroundColor != TextColor.None) {
+                // TODO: get this from ChatView
+                string tagname = GetTextTagName(null, fmsgti.BackgroundColor);
+                var tag = _MessageTextTagTable.Lookup(tagname);
+                tags.Add(tag);
+            }
+            if (fmsgti.Underline) {
+#if LOG4NET && MSG_DEBUG
+                _Logger.Debug("AddMessage(): fmsgti.Underline is true");
+#endif
+                tags.Add(UnderlineTag);
+            }
+            if (fmsgti.Bold) {
+#if LOG4NET && MSG_DEBUG
+                _Logger.Debug("AddMessage(): fmsgti.Bold is true");
+#endif
+                tags.Add(BoldTag);
+            }
+            if (fmsgti.Italic) {
+#if LOG4NET && MSG_DEBUG
+                _Logger.Debug("AddMessage(): fmsgti.Italic is true");
+#endif
+                tags.Add(ItalicTag);
+            }
+
+            if (tags.Count > 0) {
+                buffer.InsertWithTags(ref iter, fmsgti.Text, tags.ToArray());
+            } else {
+                buffer.Insert(ref iter, fmsgti.Text);
+            }
+        }
+
+        private void InsertToBuffer(Gtk.TextBuffer buffer, ref Gtk.TextIter iter, ImageMessagePartModel imgpart)
+        {
+            Uri uri = null;
+            string scheme = null;
+            try {
+                uri = new Uri(imgpart.ImageFileName);
+                scheme = uri.Scheme;
+            } catch (UriFormatException) {
+                AddAlternativeText(buffer, ref iter, imgpart);
+                return;
+            }
+            switch (scheme) {
+                case "smuxi-emoji":
+                    var shortName = uri.Host;
+                    AddEmoji(buffer, ref iter, imgpart, shortName);
+                    break;
+                default:
+                    AddAlternativeText(buffer, ref iter, imgpart);
+                    break;
+            }
+        }
+
         public void UpdateMarkerline()
         {
             Trace.Call();
