@@ -32,6 +32,9 @@ namespace Smuxi.Frontend.Stfl
 {
     public class MainWindow : Form
     {
+#if LOG4NET
+        static readonly log4net.ILog Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
+#endif
         public StflUI UI { get; private set; }
         Entry Entry { get; set; }
         public ChatViewManager ChatViewManager { get; private set; }
@@ -72,12 +75,31 @@ namespace Smuxi.Frontend.Stfl
             }
         }
 
+        public bool ShowTopic {
+            get {
+                return this["topic_hbox_display"] == "1";
+            }
+            set {
+                this["topic_hbox_display"] = value ? "1" : "0";
+            }
+        }
+
+        public string TopicLabel {
+            get {
+                return this["topic_label_text"];
+            }
+            set {
+                this["topic_label_text"] = value;
+            }
+        }
+
         public MainWindow() : base(null, "MainWindow.stfl")
         {
             ChatViewManager = new ChatViewManager(this);
             Entry = new Entry(this, ChatViewManager);
             UI = new StflUI(ChatViewManager);
 
+            Resized += OnResized;
             if (StflApi.IsXterm) {
                 ShowTitle = false;
             }
@@ -86,6 +108,17 @@ namespace Smuxi.Frontend.Stfl
             ChatViewManager.Load(asm);
         }
 
+        void OnResized(object sender, EventArgs e)
+        {
+#if LOG4NET
+            Logger.DebugFormat(
+                "OnResized(): terminal resized, columns: {0} lines: {1}",
+                this["root_vbox:w"],
+                this["root_vbox:h"]
+            );
+#endif
+        }
+
         public void ApplyConfig(UserConfig config)
         {
             Entry.ApplyConfig(config);
