@@ -48,7 +48,6 @@ namespace Smuxi.Frontend.Swf
 #endif
         private int _Version = 0;
         private ChatViewManager _ChatViewManager;
-        private IList<ChatView> _SyncedChatViews;
         private Control         _Control;
         
         public int Version {
@@ -57,12 +56,6 @@ namespace Smuxi.Frontend.Swf
             }
         }
         
-        public IList<ChatView> SyncedChatViews {
-            get {
-                return _SyncedChatViews;
-            }
-        }
-        
         public SwfUI(ChatViewManager chatViewManager, Control control)
         {
             _ChatViewManager = chatViewManager;
