@@ -1,11 +1,11 @@
 /*
- * $Id: TestUI.cs 425 2008-09-14 16:39:47Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-Test/TestUI.cs $
- * $Rev: 425 $
- * $Author: meebey $
- * $Date: 2008-09-14 18:39:47 +0200 (Sun, 14 Sep 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -111,11 +111,11 @@ namespace Smuxi.FrontendTest
             Trace.Call(cpage, olduser, newuser);
         }
     
-        public void UpdateTopicInGroupChat(GroupChatModel cpage, string topic)
+        public void UpdateTopicInGroupChat(GroupChatModel cpage, MessageModel topic)
         {
             Trace.Call(cpage, topic);
             
-            Console.WriteLine("Topic changed to: "+topic+ " on "+cpage.Name);
+            Console.WriteLine("Topic changed to: " + topic.ToString() +  " on " + cpage.Name);
         }
         
         public void RemovePersonFromGroupChat(GroupChatModel cpage, PersonModel user)
