@@ -1,13 +1,7 @@
 /*
- * $Id$
- * $URL$
- * $Rev$
- * $Author$
- * $Date$
- *
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2006, 2008, 2010 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2006, 2008, 2010, 2011, 2015  Mirco Bauer <meebey@meebey.net>
  * Copyright (c) 2010 Clement Bourgeois <moonpyk@gmail.com>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
@@ -45,6 +39,7 @@ namespace Smuxi.Server
 
         public static void Main(string[] args)
         {
+            System.Threading.Thread.CurrentThread.Name = "Main";
 #if LOG4NET
             // initialize log level
             log4net.Repository.ILoggerRepository repo = log4net.LogManager.GetRepository();
@@ -56,6 +51,7 @@ namespace Smuxi.Server
             bool modUser    = false;
             bool listUsers  = false;
             bool debug      = false;
+            string optBuffers = null;
 
             string username = null;
             string password = null;
@@ -126,6 +122,19 @@ namespace Smuxi.Server
                 }
             );
 
+            parser.Add(
+                "optimize-message-buffers=",
+                _("Optimize message buffers and exit " +
+                  "(valid values: none, defrag, index, all)"),
+                delegate (string val) {
+                    if (String.IsNullOrEmpty(val)) {
+                        val = "all";
+                    }
+                    CheckOptimizeMessageBuffersParameter(val);
+                    optBuffers = val;
+                }
+            );
+
             parser.Add(
                  "h|help",
                  _("Show this help"),
@@ -138,6 +147,16 @@ namespace Smuxi.Server
                  }
             );
 
+            parser.Add(
+                "version",
+                _("Show version"),
+                delegate(string val) {
+                    Engine.Engine.Init();
+                    Console.WriteLine(Engine.Engine.VersionString);
+                    Environment.Exit(0);
+                }
+            );
+
             parser.Add(
                  "<>",
                 delegate(string val) {
@@ -158,6 +177,9 @@ namespace Smuxi.Server
                     repo.Threshold = log4net.Core.Level.Debug;
                 }
 #endif
+                if (optBuffers != null) {
+                    OptimizeMessageBuffers(optBuffers);
+                }
                 if (addUser || modUser) {
                     CheckUsernameParameter(username);
                     CheckPasswordParameter(password);
@@ -249,6 +271,28 @@ namespace Smuxi.Server
             }
         }
 
+        private static void CheckOptimizeMessageBuffersParameter(string opts)
+        {
+            try {
+                ParseBufferOptimizationTypes(opts);
+            } catch (Exception) {
+                var validOpts = Enum.GetNames(typeof(Db4oMessageBufferOptimizationTypes));
+                // lower-case values
+                for (int i = 0; i < validOpts.Length; i++) {
+                    validOpts[i] = validOpts[i].ToLower();
+                }
+                var validValues = String.Join(", ", validOpts);
+                throw new OptionException(
+                    String.Format(
+                        _("Invalid optimization value passed to " +
+                          "--optimize-message-buffer, valid values are: {0}"),
+                        validValues
+                    ),
+                    String.Empty
+                );
+            }
+        }
+
         private static void ManageUser(bool addUser, bool delUser, bool modUser,
                                        bool listUsers,
                                        string username, string password)
@@ -297,6 +341,63 @@ namespace Smuxi.Server
             }
         }
 
+        private static Db4oMessageBufferOptimizationTypes ParseBufferOptimizationTypes(string optString)
+        {
+            if (optString == null) {
+                throw new ArgumentNullException("optString");
+            }
+
+            var optList = optString.Split(' ', ',');
+            var opts = Db4oMessageBufferOptimizationTypes.None;
+            foreach (var optItem in optList) {
+                var optEnum = (Db4oMessageBufferOptimizationTypes) Enum.Parse(
+                    typeof(Db4oMessageBufferOptimizationTypes),
+                    optItem,
+                    true
+                );
+                opts |= optEnum;
+            }
+            return opts;
+        }
+
+        private static void OptimizeMessageBuffers(string optString)
+        {
+            var logRepo = log4net.LogManager.GetRepository();
+            var origThreshold = logRepo.Threshold;
+            // don't spew errors of Db4oMessageBuffer
+            if (origThreshold == log4net.Core.Level.Error) {
+                logRepo.Threshold = log4net.Core.Level.Fatal;
+            }
+            try {
+                var opts = ParseBufferOptimizationTypes(optString);
+                if (opts == Db4oMessageBufferOptimizationTypes.None) {
+                    Environment.Exit(0);
+                    return;
+                }
+                var bufferCount = Db4oMessageBuffer.OptimizeAllBuffers(opts);
+                Console.WriteLine(
+                    String.Format(
+                        _("Successfully optimized {0} message buffers."),
+                        bufferCount
+                    )
+                );
+                Environment.Exit(0);
+            } catch (Exception ex) {
+                string error = ex.Message;
+                if (ex.InnerException != null) {
+                    // inner-exceptio is more useful for some reason...
+                    error = ex.InnerException.Message;
+                }
+                Console.WriteLine(
+                    String.Format(
+                        _("Failed to optimize message buffers: {0}"), error
+                    )
+                );
+                Environment.Exit(1);
+            }
+            logRepo.Threshold = origThreshold;
+        }
+
         private static string _(string msg)
         {
             return LibraryCatalog.GetString(msg, _LibraryTextDomain);
